from distutils.core import setup

setup(
    name='mlkit_lyt',
    packages=['mlkit_lyt', 'mlkit_lyt.KNN', 'mlkit_lyt.logistic', 'mlkit_lyt.common'],
    author='lyt0628',
    author_email='lyt.0628@qq.com',
    url='http://lyt0628.icu',
    download_url='http://github.com//LYT0628/mllearn',
    description='Machine Learning in Python'
)
